@@ -1,12 +1,14 @@
 from time import sleep
 from unittest import SkipTest
+from unittest.case import skipIf
 
 from parameterized import parameterized
 from tenacity import retry, retry_if_exception, stop_after_attempt
 
+from integration.config.service_names import SCHEDULE_EVENT
 from integration.conftest import clean_bucket
-from integration.helpers.base_test import S3_BUCKET_PREFIX, BaseTest
-from integration.helpers.resource import generate_suffix
+from integration.helpers.base_test import S3_BUCKET_PREFIX, BaseTest, nonblocking
+from integration.helpers.resource import current_region_does_not_support, generate_suffix
 
 retry_once = retry(
     stop=stop_after_attempt(2),
@@ -15,6 +17,37 @@ retry_once = retry(
 )
 
 
+# Explicitly move EB tests out to handlle the failed test in some regions.
+# In those regions, the tests should have been skipped but somehow not.
+# Test using `skipIf` to see if it helps.
+@skipIf(
+    current_region_does_not_support([SCHEDULE_EVENT]),
+    "SCHEDULE_EVENT is not supported in this testing region",
+)
+@nonblocking
+class TestConnectorsWithEventBus(BaseTest):
+    @parameterized.expand(
+        [
+            ("combination/connector_function_to_eventbus_write",),
+        ]
+    )
+    @retry_once
+    def test_connector_by_invoking_a_function_with_eventbus(self, template_file_path):
+        self.create_and_verify_stack(template_file_path)
+
+        lambda_function_name = self.get_physical_id_by_logical_id("TriggerFunction")
+        lambda_client = self.client_provider.lambda_client
+
+        request_params = {
+            "FunctionName": lambda_function_name,
+            "InvocationType": "RequestResponse",
+            "Payload": "{}",
+        }
+        response = lambda_client.invoke(**request_params)
+        self.assertEqual(response.get("StatusCode"), 200)
+        self.assertEqual(response.get("FunctionError"), None)
+
+
 class TestConnectors(BaseTest):
     def tearDown(self):
         # Some tests will create items in S3 Bucket, which result in stack DELETE_FAILED state
@@ -42,7 +75,6 @@ class TestConnectors(BaseTest):
             ("combination/connector_function_to_queue_write",),
             ("combination/connector_function_to_queue_read",),
             ("combination/connector_function_to_topic_write",),
-            ("combination/connector_function_to_eventbus_write",),
             ("combination/connector_topic_to_queue_write",),
             ("combination/connector_event_rule_to_sqs_write",),
             ("combination/connector_event_rule_to_sns_write",),
