@@ -10,7 +10,7 @@ from samtranslator.model.eventsources.push import Api as PushApi
 from samtranslator.model.exceptions import InvalidEventException
 from samtranslator.model.iam import IAMRole, IAMRolePolicies
 from samtranslator.model.intrinsics import fnSub
-from samtranslator.model.types import IS_DICT, IS_STR, PassThrough, is_type
+from samtranslator.model.types import IS_BOOL, IS_DICT, IS_STR, PassThrough
 from samtranslator.swagger.swagger import SwaggerEditor
 from samtranslator.translator import logical_id_generator
 
@@ -86,7 +86,7 @@ class Schedule(EventSource):
     property_types = {
         "Schedule": PropertyType(True, IS_STR),
         "Input": PropertyType(False, IS_STR),
-        "Enabled": PropertyType(False, is_type(bool)),
+        "Enabled": PropertyType(False, IS_BOOL),
         "State": PropertyType(False, IS_STR),
         "Name": PropertyType(False, IS_STR),
         "Description": PropertyType(False, IS_STR),
@@ -193,6 +193,7 @@ class CloudWatchEvent(EventSource):
         "RetryPolicy": PropertyType(False, IS_DICT),
         "State": PropertyType(False, IS_STR),
         "Target": Property(False, IS_DICT),
+        "InputTransformer": PropertyType(False, IS_DICT),
     }
 
     EventBusName: Optional[PassThrough]
@@ -204,6 +205,7 @@ class CloudWatchEvent(EventSource):
     RetryPolicy: Optional[PassThrough]
     State: Optional[PassThrough]
     Target: Optional[PassThrough]
+    InputTransformer: Optional[PassThrough]
 
     @cw_timer(prefix=SFN_EVETSOURCE_METRIC_PREFIX)
     def to_cloudformation(self, resource, **kwargs):  # type: ignore[no-untyped-def]
@@ -273,6 +275,9 @@ class CloudWatchEvent(EventSource):
         if self.RetryPolicy is not None:
             target["RetryPolicy"] = self.RetryPolicy
 
+        if self.InputTransformer is not None:
+            target["InputTransformer"] = self.InputTransformer
+
         return target
 
 
@@ -294,7 +299,7 @@ class Api(EventSource):
         "RestApiId": PropertyType(True, IS_STR),
         "Stage": PropertyType(False, IS_STR),
         "Auth": PropertyType(False, IS_DICT),
-        "UnescapeMappingTemplate": Property(False, is_type(bool)),
+        "UnescapeMappingTemplate": Property(False, IS_BOOL),
     }
 
     Path: str
@@ -362,9 +367,7 @@ class Api(EventSource):
             # Cannot add the integration, if it is already present
             raise InvalidEventException(
                 self.relative_id,
-                'API method "{method}" defined multiple times for path "{path}".'.format(
-                    method=self.Method, path=self.Path
-                ),
+                f'API method "{self.Method}" defined multiple times for path "{self.Path}".',
             )
 
         condition = None
